exceptiontools.NoteHeadError
============================

.. abjad-lineage:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError

.. autoclass:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.NoteHeadError.NoteHeadError.__unicode__
   :noindex:
